Class: Guard::FixtureBuilder
- Defined in:
- lib/guard/fixture_builder.rb
Instance Method Summary collapse
-
#initialize(watchers = [], options = {}) ⇒ FixtureBuilder
constructor
Initialize a Guard.
-
#reload ⇒ Object
Called when
reload|r|z + enteris pressed. -
#run_all ⇒ Object
Called when just
enteris pressed This method should be principally used for long action like running all specs/tests/... -
#run_on_changes(paths) ⇒ Object
Called on file(s) modifications that the Guard watches.
-
#run_on_removals(paths) ⇒ Object
Called on file(s) deletions that the Guard watches.
-
#start ⇒ Object
Call once when Guard starts.
-
#stop ⇒ Object
Called when
stop|quit|exit|s|q|e + enteris pressed (when Guard quits).
Constructor Details
#initialize(watchers = [], options = {}) ⇒ FixtureBuilder
Initialize a Guard.
9 10 11 |
# File 'lib/guard/fixture_builder.rb', line 9 def initialize(watchers = [], = {}) super end |
Instance Method Details
#reload ⇒ Object
Called when reload|r|z + enter is pressed.
This method should be mainly used for "reload" (really!) actions like reloading passenger/spork/bundler/...
27 28 |
# File 'lib/guard/fixture_builder.rb', line 27 def reload end |
#run_all ⇒ Object
Called when just enter is pressed
This method should be principally used for long action like running all specs/tests/...
33 34 |
# File 'lib/guard/fixture_builder.rb', line 33 def run_all end |
#run_on_changes(paths) ⇒ Object
Called on file(s) modifications that the Guard watches.
39 40 41 |
# File 'lib/guard/fixture_builder.rb', line 39 def run_on_changes(paths) run_fixture_builder end |
#run_on_removals(paths) ⇒ Object
Called on file(s) deletions that the Guard watches.
46 47 |
# File 'lib/guard/fixture_builder.rb', line 46 def run_on_removals(paths) end |
#start ⇒ Object
Call once when Guard starts. Please override initialize method to init stuff.
15 16 17 |
# File 'lib/guard/fixture_builder.rb', line 15 def start run_fixture_builder end |
#stop ⇒ Object
Called when stop|quit|exit|s|q|e + enter is pressed (when Guard quits).
21 22 |
# File 'lib/guard/fixture_builder.rb', line 21 def stop end |